==> humhub-1.15.0-beta.1.tar.gz: humhub-1.15.0-beta.1/protected/humhub/modules/admin/messages/th/space.php <==
<?php

return [
    '<strong>Manage</strong> Spaces' => '<strong>จัดการ</strong> ช่องว่าง',
    'Add new space' => 'เพิ่มพื้นที่ใหม่',
    'By using user roles, you can create different permission groups within a Space. These can also be individualized by authorized users for each and every Space and are only relevant for that specific Space.' => 'เมื่อใช้บทบาทของผู้ใช้ คุณจะสร้างกลุ่มสิทธิ์ต่างๆ ภายใน Space ได้ ผู้ใช้ที่ได้รับอนุญาตเหล่านี้ยังสามารถกำหนดเป็นรายบุคคลได้สำหรับแต่ละ Space และเกี่ยวข้องกับ Space นั้นเท่านั้น',
    'Change owner' => 'เปลี่ยนเจ้าของ',
    'Default Content Visiblity' => 'การแสดงเนื้อหาเริ่มต้น',
    'Default Join Policy' => 'นโยบายเข้าร่วมเริ่มต้น',
    'Default Space Permissions' => 'สิทธิ์พื้นที่เริ่มต้น',
    'Default Space(s)' => 'ช่องว่างเริ่มต้น',
    'Default Visibility' => 'การมองเห็นเริ่มต้น',
    'Default space' => 'ช่องว่างเริ่มต้น',
    'Here you can define your default settings for new spaces. These settings can be overwritten for each individual space.' => 'คุณสามารถกำหนดการตั้งค่าเริ่มต้นสำหรับช่องว่างใหม่ได้ที่นี่ การตั้งค่าเหล่านี้สามารถเขียนทับได้สำหรับแต่ละพื้นที่',
    'Invalid space' => 'ช่องว่างไม่ถูกต้อง',
    'Manage members' => 'จัดการสมาชิก',
    'Manage modules' => 'จัดการโมดูล',
    'Open space' => 'ลาน',
    'Overview' => 'ภาพรวม',
    'Permissions' => 'สิทธิ์',
    'Search by name, description, id or owner.' => 'ค้นหาตามชื่อ คำอธิบาย รหัสหรือเจ้าของ',
    'Settings' => 'การตั้งค่า',
    'Space Settings' => 'การตั้งค่าพื้นที่',
    'These options allow you to set the default permissions for all Spaces. Authorized users are able individualize these for each Space. Further entries are added with the installation of new modules.' => 'ตัวเลือกเหล่านี้อนุญาตให้คุณตั้งค่าการอนุญาตเริ่มต้นสำหรับ Space ทั้งหมด ผู้ใช้ที่ได้รับอนุญาตจะสามารถปรับแต่งสิ่งเหล่านี้สำหรับแต่ละ Space มีการเพิ่มรายการเพิ่มเติมด้วยการติดตั้งโมดูลใหม่',
    'This overview contains a list of each space with actions to view, edit and delete spaces.' => 'ภาพรวมนี้ประกอบด้วยรายการของแต่ละพื้นที่พร้อมการดำเนินการเพื่อดู แก้ไข และลบพื้นที่',
    'Update Space memberships also for existing members.' => 'อัปเดตการเป็นสมาชิก Space สำหรับสมาชิกปัจจุบันด้วย',
    'Default "Hide About Page"' => '',
    'Default "Hide Activity Sidebar Widget"' => '',
    'Default "Hide Followers"' => '',
    'Default "Hide Members"' => '',
    'Default homepage' => '',
    'Default homepage (Non-members)' => '',
];

==> humhub-1.17.0-beta.1.tar.gz: humhub-1.17.0-beta.1/protected/humhub/modules/admin/messages/th/space.php <==
<?php

return [
    '<strong>Manage</strong> Spaces' => '<strong>จัดการ</strong> ช่องว่าง',
    'Add new space' => 'เพิ่มพื้นที่ใหม่',
    'By using user roles, you can create different permission groups within a Space. These can also be individualized by authorized users for each and every Space and are only relevant for that specific Space.' => 'เมื่อใช้บทบาทของผู้ใช้ คุณจะสร้างกลุ่มสิทธิ์ต่างๆ ภายใน Space ได้ ผู้ใช้ที่ได้รับอนุญาตเหล่านี้ยังสามารถกำหนดเป็นรายบุคคลได้สำหรับแต่ละ Space และเกี่ยวข้องกับ Space นั้นเท่านั้น',
    'Change owner' => 'เปลี่ยนเจ้าของ',
    'Default Content Visiblity' => 'การแสดงเนื้อหาเริ่มต้น',
    'Default Join Policy' => 'นโยบายเข้าร่วมเริ่มต้น',
    'Default Space Permissions' => 'สิทธิ์พื้นที่เริ่มต้น',
    'Default Space(s)' => 'ช่องว่างเริ่มต้น',
    'Default Visibility' => 'การมองเห็นเริ่มต้น',
    'Default space' => 'ช่องว่างเริ่มต้น',
    'Here you can define your default settings for new spaces. These settings can be overwritten for each individual space.' => 'คุณสามารถกำหนดการตั้งค่าเริ่มต้นสำหรับช่องว่างใหม่ได้ที่นี่ การตั้งค่าเหล่านี้สามารถเขียนทับได้สำหรับแต่ละพื้นที่',
    'Invalid space' => 'ช่องว่างไม่ถูกต้อง',
    'Manage members' => 'จัดการสมาชิก',
    'Manage modules' => 'จัดการโมดูล',
    'Open space' => 'ลาน',
    'Overview' => 'ภาพรวม',
    'Permissions' => 'สิทธิ์',
    'Search by name, description, id or owner.' => 'ค้นหาตามชื่อ คำอธิบาย รหัสหรือเจ้าของ',
    'Settings' => 'การตั้งค่า',
    'Space Settings' => 'การตั้งค่าพื้นที่',
    'These options allow you to set the default permissions for all Spaces. Authorized users are able individualize these for each Space. Further entries are added with the installation of new modules.' => 'ตัวเลือกเหล่านี้อนุญาตให้คุณตั้งค่าการอนุญาตเริ่มต้นสำหรับ Space ทั้งหมด ผู้ใช้ที่ได้รับอนุญาตจะสามารถปรับแต่งสิ่งเหล่านี้สำหรับแต่ละ Space มีการเพิ่มรายการเพิ่มเติมด้วยการติดตั้งโมดูลใหม่',
    'This overview contains a list of each space with actions to view, edit and delete spaces.' => 'ภาพรวมนี้ประกอบด้วยรายการของแต่ละพื้นที่พร้อมการดำเนินการเพื่อดู แก้ไข และลบพื้นที่',
    'Update Space memberships also for existing members.' => 'อัปเดตการเป็นสมาชิก Space สำหรับสมาชิกปัจจุบันด้วย',
    'Default "Hide About Page"' => '',
    'Default "Hide Activity Sidebar Widget"' => '',
    'Default "Hide Followers"' => '',
    'Default "Hide Members"' => '',
    'Default Homepage' => '',
    'Default Homepage (Non-members)' => '',
    'Default Stream Sort' => '',
];
